@@ -2,6 +2,14 @@ import os
 import sys
 
 
+def to_bool(value):
+    """Converts a string to a bool"""
+    stringValue = str(value).lower()
+    if stringValue in ["true", "yes", "on", "1"]:
+        return True
+    return False
+
+
 class Config:
     """Object that holds config values.
 
@@ -14,6 +22,12 @@ class Config:
       form "user1:hash1,user2:hash2" where each hash is a salted hash (BCrypt)
       of the password. Used in the default startup script ``__main__.py``.
       You can generate credentials with https://timetagger.app/cred.
+    * `proxy_auth_enabled (bool)`: enables authentication from a reverse proxy
+      (for example Authelia). Default "False".
+    * `proxy_auth_trusted (str)`: list of trusted reverse proxy IPs, in the
+      form "127.0.0.1,10.0.0.1". Default "127.0.0.1".
+    * `proxy_auth_header (str)`: name of the proxy header which contains the
+      username of the logged in user. Default "X-Remote-User".
 
     The values can be configured using CLI arguments and environment variables.
     For CLI arguments, the following formats are supported:
@@ -33,6 +47,9 @@ class Config:
         ("datadir", str, "~/_timetagger"),
         ("log_level", str, "info"),
         ("credentials", str, ""),
+        ("proxy_auth_enabled", to_bool, False),
+        ("proxy_auth_trusted", str, "127.0.0.1"),
+        ("proxy_auth_header", str, "X-Remote-User"),
     ]
     __slots__ = [name for name, _, _ in _ITEMS]
 
